<center>

[![GitHub](https://img.shields.io/github/license/nhqml/izitest)](https://github.com/Nhqml/izitest/blob/master/LICENSE)

[![PyPI](https://img.shields.io/pypi/v/izitest)](https://pypi.org/project/izitest/)
![PyPI - Status](https://img.shields.io/pypi/status/izitest)

[![Read the Docs](https://img.shields.io/readthedocs/izitest)](https://izitest.rtfd.io)

# izitest
### *An easy way to test executables against a test suite*

WIP... please be patient.

</center>
